@@ -2,7 +2,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw_ufraw.c - program interface to all the components
- * Copyright 2004-2014 by Udi Fuchs
+ * Copyright 2004-2015 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -351,7 +351,7 @@ int ufraw_load_darkframe(ufraw_data *uf)
     return UFRAW_SUCCESS;
 }
 
-// Get the dimensions of the unshrunk, rotated image.
+// Get the dimensions of the unshrunk, rotated image.autoCrop
 // The crop coordinates are calculated based on these dimensions.
 void ufraw_get_image_dimensions(ufraw_data *uf)
 {
@@ -360,12 +360,14 @@ void ufraw_get_image_dimensions(ufraw_data *uf)
 
     ufraw_get_image(uf, ufraw_transform_phase, FALSE);
 
-    if (uf->conf->CropX1 < 0) uf->conf->CropX1 = 0;
-    if (uf->conf->CropY1 < 0) uf->conf->CropY1 = 0;
-    if (uf->conf->CropX2 < 0) uf->conf->CropX2 = uf->rotatedWidth;
-    if (uf->conf->CropY2 < 0) uf->conf->CropY2 = uf->rotatedHeight;
+    if (uf->conf->fullCrop || uf->conf->CropX1 < 0) uf->conf->CropX1 = 0;
+    if (uf->conf->fullCrop || uf->conf->CropY1 < 0) uf->conf->CropY1 = 0;
+    if (uf->conf->fullCrop || uf->conf->CropX2 < 0) uf->conf->CropX2 = uf->rotatedWidth;
+    if (uf->conf->fullCrop || uf->conf->CropY2 < 0) uf->conf->CropY2 = uf->rotatedHeight;
 
-    if (uf->conf->aspectRatio <= 0) {
+    if (uf->conf->fullCrop)
+        uf->conf->aspectRatio = (double)uf->rotatedWidth / uf->rotatedHeight;
+    else if (uf->conf->aspectRatio <= 0) {
         if (uf->conf->autoCrop)
             /* preserve the initial aspect ratio - this should be consistent
                with ufraw_convert_prepare_transform */
@@ -1320,8 +1322,8 @@ static void ufraw_convert_image_tca(ufraw_data *uf, ufraw_image_data *img,
                 float srcX = modcoord[0];
                 float srcY = modcoord[1];
                 /* Do it in integer arithmetic, it's faster */
-                int xx = (int)floor(srcX + 0.5);
-                int yy = (int)floor(srcY + 0.5);
+                int xx = (int)srcX;
+                int yy = (int)srcY;
                 // TODO: better handling of the borders.
                 if (xx < 0 || yy < 0 || xx + 1 >= img->width || yy + 1 >= img->height) {
                     dst[c] = 0;
